@@ -167,7 +167,7 @@ sub descend
 	my %varnums = Sim::OPT::getcase(\@varinumbers, $countcase); 
 	my %mids = Sim::OPT::getcase(\@miditers, $countcase); 
 
-	my $word = ( "_", @blockelts ); ###NEW
+	my $word = join( ", ", @blockelts ); ###NEW
 	
 	my $stepsvar = Sim::OPT::getstepsvar($countvar, $countcase, \@varinumbers); 
 	my $varnumber = $countvar; 
